@@ -5,7 +5,7 @@ use utf8;
 
 package Dist::Zilla::Util::Test::KENTNL::dztest;
 
-our $VERSION = '1.004002';
+our $VERSION = '1.005000';
 
 # ABSTRACT: Shared dist testing logic for easy dzil things
 
@@ -22,10 +22,9 @@ use Dist::Zilla::App::Tester qw( test_dzil );
 use Module::Runtime qw();
 
 ## no critic (ValuesAndExpressions::ProhibitConstantPragma,ErrorHandling::RequireCheckingReturnValueOfEval,Subroutines::ProhibitSubroutinePrototypes)
-use constant CAN_DPATH    => eval { require Data::DPath;       1 };
-use constant CAN_EQORDIFF => eval { require Test::Differences; 1 };
+use recommended 'Data::DPath', 'Test::Differences', 'Test::TempDir::Tiny';
 sub dpath($);
-BEGIN { CAN_DPATH and Data::DPath->import('dpath') }
+BEGIN { recommended->has('Data::DPath') and Data::DPath->import('dpath') }
 ## use critic
 
 
@@ -105,7 +104,7 @@ sub _subtest_prereqs_deeply {
   $self->tb->ok( defined $meta, 'distmeta defined' );
   $self->tb->note( $self->tb->explain( $meta->{prereqs} ) );
 
-  if (CAN_EQORDIFF) {
+  if ( recommended->has('Test::Differences') ) {
     Test::Differences::eq_or_diff( $meta->{prereqs}, $prereqs, 'Prereqs match expected set' );
   }
   else {
@@ -212,7 +211,7 @@ EOF
   my (@results) = dpath($expression)->match( $self->builder->distmeta );
   $self->tb->ok( @results > 0, "distmeta matched expression $expression" );
   $self->tb->note( $self->tb->explain( \@results ) );
-  if (CAN_EQORDIFF) {
+  if ( recommended->has('Test::Differences') ) {
     Test::Differences::eq_or_diff( \@results, $expected, 'distmeta matched expectations' );
   }
   else {
@@ -240,7 +239,7 @@ sub meta_path_deeply {
   return $self->tb->subtest(
     $reason => sub {
       $self->tb->plan( tests => 2 );
-      if (CAN_DPATH) {
+      if ( recommended->has('Data::DPath') ) {
         return $self->_subtest_meta_path_deeply( $expression, $expected );
       }
       return $self->_todo_meta_path_deeply($expression);
@@ -339,7 +338,13 @@ has tempdir => (
 
 sub _build_tempdir {
   my ($self) = @_;
-  my $tempdir = Path::Tiny->tempdir;
+  my $tempdir;
+  if ( recommended->has('Test::TempDir::Tiny') ) {
+    $tempdir = path( Test::TempDir::Tiny::tempdir() );
+  }
+  else {
+    $tempdir = Path::Tiny->tempdir;
+  }
   $self->tb->note("Creating fake dist in $tempdir");
   return $tempdir;
 }
@@ -568,7 +573,7 @@ Dist::Zilla::Util::Test::KENTNL::dztest - Shared dist testing logic for easy dzi
 
 =head1 VERSION
 
-version 1.004002
+version 1.005000
 
 =head1 SYNOPSIS
 
@@ -762,7 +767,7 @@ Construct the internal builder object.
 
   $test->configure;
 
-=for Pod::Coverage CAN_DPATH build CAN_EQORDIFF
+=for Pod::Coverage build
 
 =head1 AUTHOR
 
